.. geo3d documentation master file, created by
   sphinx-quickstart on Fri Sep  4 14:05:03 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to geo3d's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   basic_usage
   queries



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
